@@ -5,7 +5,7 @@ use warnings;
 use HTTP::Tiny;
 use JSON;
 
-$Yandex::Translate::VERSION = '0.04';
+$Yandex::Translate::VERSION = '1.0';
 
 sub new
 {
@@ -116,7 +116,7 @@ Yandex::Translate - An Api, simple, for Yandex translate
  
 =head1 VERSION
 
-    version 0.03
+    version 1.0
  
 =head1 SYNOPSIS
 
@@ -159,23 +159,23 @@ on the analysis of millions of translated texts.
 
     $tr = Yandex->Translate->new( %attributes );
 
-This constructor return a new Yandex::Translate object, optionel  attributes
+This constructor return a new Yandex::Translate object, optionel attributes (see examples directory).
 include:
 
-*-key  -- Key Api that you can get from yandex website after register, string format
+*-key  -- Key Api, you should get it from yandex website after register, string format.
 
-*-text -- Text that you want to translate, strring format.
+*-text -- Text that you want to translate, string format.
 
 *-from_lang -- The source lang, string format.
 
-*-to_lang -- the distination lang, string lang.
+*-to_lang -- the distination lang, string format.
 
 =item  set_key
 
     $tr->set_key( 'yandex_key' ); 
     
-This method can help you to pass api key (string), instead of passing in 'new'
-you can define an oject without any attributes.
+This method is used to pass an api key (string), instead of pass it in 'new' 
+you can define an object without any attributes (I like methods way).
 
 =item  set_text
 
@@ -187,25 +187,25 @@ This method is used to pass your text to translate (string).
 
     $tr->set_from_lang( 'en' );
     
-This method is used to pass your source lang (string) from example english => 'en'.
+This method is used to pass your source lang (string), example english => 'en'.
 
 =item  set_to_lang
 
     $tr->set_to_lang( 'xx' );
 
-This method is used to pass your destination lang (string) from example arabic => 'ar'.
+This method is used to pass your destination lang (string) for example arabic => 'ar'.
 
 =item  translate
 
     print  $tr->translate();
 
-This method is used to get the text translated, It returns a string.
+This method is used to get the result, It returns a string.
 
 =item  detect_lang
 
     print  $tr->detect_lang();
 
-This method is used to detect a language of the text, It returns a string.
+This method is used to detect the language of the text, It returns a string.
 
 =item  get_langs_list
 
